==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/GridDataCommittingEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var GridDataCommittingEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridDataCommittingEventArgsDescription, _super);
    function GridDataCommittingEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        _this.h = 0;
        return _this;
    }
    GridDataCommittingEventArgsDescription.prototype.get_type = function () {
        return "GridDataCommittingEventArgs";
    };
    Object.defineProperty(GridDataCommittingEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(GridDataCommittingEventArgsDescription.prototype, "changes", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Changes");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(GridDataCommittingEventArgsDescription.prototype, "commitID", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("CommitID");
        },
        enumerable: true,
        configurable: true
    });
    GridDataCommittingEventArgsDescription.$t = markType(GridDataCommittingEventArgsDescription, 'GridDataCommittingEventArgsDescription', Description.$);
    return GridDataCommittingEventArgsDescription;
}(Description));
export { GridDataCommittingEventArgsDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/GridDataCommittingEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var GridDataCommittingEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridDataCommittingEventArgsDescription, _super);
    function GridDataCommittingEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.h = null;
        _this.j = 0;
        return _this;
    }
    GridDataCommittingEventArgsDescription.prototype.get_type = function () {
        return "GridDataCommittingEventArgs";
    };
    Object.defineProperty(GridDataCommittingEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GridDataCommittingEventArgsDescription.prototype, "changes", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("Changes");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GridDataCommittingEventArgsDescription.prototype, "commitID", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g("CommitID");
        },
        enumerable: false,
        configurable: true
    });
    GridDataCommittingEventArgsDescription.$t = markType(GridDataCommittingEventArgsDescription, 'GridDataCommittingEventArgsDescription', Description.$);
    return GridDataCommittingEventArgsDescription;
}(Description));
export { GridDataCommittingEventArgsDescription };
